==> kubernetes-model-core-5.7.4-sources.jar: io/fabric8/kubernetes/api/model/NamedContextFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NamedContextFluent<A extends io.fabric8.kubernetes.api.model.NamedContextFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildContext instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.Context getContext();
  public io.fabric8.kubernetes.api.model.Context buildContext();
  public A withContext(io.fabric8.kubernetes.api.model.Context context);
  public java.lang.Boolean hasContext();
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> withNewContext();
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> withNewContextLike(io.fabric8.kubernetes.api.model.Context item);
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> editContext();
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> editOrNewContext();
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> editOrNewContextLike(io.fabric8.kubernetes.api.model.Context item);
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public interface ContextNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ContextFluent<io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<N>>{
    public N and();
    public N endContext();
    
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/NamedContextFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NamedContextFluent<A extends io.fabric8.kubernetes.api.model.NamedContextFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildContext instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.Context getContext();
  public io.fabric8.kubernetes.api.model.Context buildContext();
  public A withContext(io.fabric8.kubernetes.api.model.Context context);
  public java.lang.Boolean hasContext();
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> withNewContext();
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> withNewContextLike(io.fabric8.kubernetes.api.model.Context item);
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> editContext();
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> editOrNewContext();
  public io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<A> editOrNewContextLike(io.fabric8.kubernetes.api.model.Context item);
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ContextNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ContextFluent<io.fabric8.kubernetes.api.model.NamedContextFluent.ContextNested<N>>{
    public N and();
    public N endContext();
    
  }
  
}
